import { Input, Card, Select, Button, Form, InputNumber, message } from 'antd';
import { useEffect, useState } from 'react';
import { history } from 'umi';
import ProCard from '@ant-design/pro-card';
import ExtendContent from '@/components/ExtendContent';
import { UploadImage } from '@/components/Upload';
import { getNewsTypeList } from '@/services/newsType';
import { addNews, updateNews, getNewsDetail } from '@/services/news';

const { Option } = Select;
const goBack = () => {
  history.goBack();
};
const FormItem = Form.Item;
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [newsTypeList, setNewsTypeList] = useState([]);

  const formItemLayout = {
    //布局
    labelCol: { span: 6 },
    wrapperCol: { span: 14 },
  };

  const Submit = (data) => {
    setLoading(true);
    if (id) {
      updateNews(id, data)
        .then(() => {
          setLoading(false);
          message.success('数据更新成功');
          goBack();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    } else {
      addNews(data)
        .then((res) => {
          setLoading(false);
          message.success('数据保存成功');
          history.replace(`./edit.jsx?id=${res.newsId}`);
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    }
  };
  useEffect(() => {
    getNewsTypeList().then((res) => {
      setNewsTypeList(res.records);
    });
  }, []);
  useEffect(() => {
    if (id) {
      getNewsDetail(id).then((res) => {
        form.setFieldsValue(res);
      });
    }
  }, [id]);
  return (
    <Card>
      <ProCard tabs={{ type: 'card' }} style={{ marginTop: '16px' }}>
        <ProCard.TabPane key={1} tab="资讯管理">
          <Form {...formItemLayout} onFinish={Submit} form={form}>
            <FormItem label="标题" name="title" rules={[{ required: true, message: '请输入' }]}>
              <Input placeholder="请输入" style={{ width: '350px' }} />
            </FormItem>
            <FormItem
              label="资讯分类"
              name="typeId"
              rules={[{ required: true, message: '请选择' }]}
            >
              <Select placeholder="请选择" allowClear style={{ width: '350px' }}>
                {newsTypeList.map((item) => (
                  <Option value={item.typeId} key={item.typeId}>
                    {item.name}
                  </Option>
                ))}
              </Select>
            </FormItem>
            <FormItem label="封面" name="thumb" rules={[{ required: true, message: '请输入' }]}>
              <UploadImage />
            </FormItem>
            <FormItem label="权重" name="weight" rules={[{ required: true, message: '请输入' }]}>
              <InputNumber min={0} placeholder="请输入权重" style={{ width: '350px' }} />
            </FormItem>
            <FormItem label="状态" name="status" rules={[{ required: true, message: '请选择' }]}>
              <Select placeholder="请选择是否发布" style={{ width: '350px' }}>
                <Option value={1}>发布</Option>
                <Option value={0}>未发布</Option>
              </Select>
            </FormItem>
            {id && (
              <FormItem label="详细信息" colon={false}>
                <ExtendContent targetType="info" targetId={id} onCancel={() => history.goBack()} />
              </FormItem>
            )}
            <FormItem label=" " colon={false}>
              <Button type="default" onClick={() => goBack()}>
                返回
              </Button>
              <Button
                type="primary"
                loading={loading}
                htmlType="Submit"
                style={{ marginLeft: '4em' }}
              >
                保存
              </Button>
            </FormItem>
          </Form>
        </ProCard.TabPane>
      </ProCard>
    </Card>
  );
};
