import React, { useRef, useEffect, useState } from 'react';
import { history } from 'umi';
import { Button, Popconfirm, message, Select, Modal } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable';
import moment from 'moment';
import { getNewsList, deleteNews, updateNews } from '@/services/news';
import { getNewsTypeList } from '@/services/newsType';

const formatterTime = (val) => {
  return val && val !== '-' ? moment(val).format('YYYY-MM-DD') : '-';
};
const { Option } = Select;

export default (props) => {
  const actionRef = useRef();
  const [newsTypeList, setNewsTypeList] = useState([]);

  const gotoEdit = (id) => {
    const queryStr = id ? `?id=${id}` : '';
    history.push(`./informationList/edit.jsx${queryStr}`);
  };
  const handleDelete = (id) => {
    deleteNews(id).then(() => {
      message.success('删除成功');
      actionRef.current.reload();
    });
  };
  //列表切换资讯状态方法
  const handleOK = (record, data) => {
    const title = record.status
      ? '您确定要将该资讯状态变更为未发布吗? 变更后该资讯将不在移动端显示'
      : '您确定要将该资讯状态变更为发布吗? 发布后该资讯可以在移动端显示';
    Modal.confirm({
      title: title,
      okText: '确认',
      cancelText: '取消',
      onOk() {
        updateNews(record.newsId, { ...record, status: record.status === 1 ? 0 : 1 })
          .then((res) => {
            message.success('操作成功');
            actionRef.current.reload();
          })
          .catch((err) => {
            message.error(err);
          });
      },
    });
  };
  useEffect(() => {
    getNewsTypeList().then((res) => {
      setNewsTypeList(res.records);
    });
  }, []);
  const actions = () => [
    <Button key="add" type="primary" icon={<PlusOutlined />} onClick={() => gotoEdit()}>
      新增
    </Button>,
  ];
  const columns = [
    {
      title: '标题',
      dataIndex: 'title',
      key: 'title',
    },
    {
      title: '资讯类型',
      dataIndex: 'typeId',
      key: 'typeId',
      renderFormItem: (item, field, form) => {
        return (
          <Select style={{ width: '350px' }}>
            {newsTypeList.map((item) => (
              <Option value={item.typeId} key={item.typeId}>
                {item.name}
              </Option>
            ))}
          </Select>
        );
      },
      hideInTable: true,
    },
    {
      title: '资讯分类',
      dataIndex: 'typeName',
      key: 'typeName',
      search: false,
      width: 240,
    },
    {
      title: '封面',
      dataIndex: 'thumb',
      key: 'thumb',
      width: 150,
      render: (t) => <img width={110} src={t} alt="" />,
      search: false,
    },
    {
      title: '权重',
      dataIndex: 'weight',
      key: 'weight',
      search: false,
      width: 100,
    },
    {
      title: '创建时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: formatterTime,
      search: false,
      width: 100,
    },
    {
      title: '发布状态',
      dataIndex: 'status',
      key: 'status',
      search: false,
      width: 100,
      render: (_, record) => {
        return record.status === 1 ? '发布' : '未发布';
      },
    },
    {
      title: '操作',
      valueType: 'option',
      width: 240,
      render: (_, record) => [
        <Button style={{ padding: 0 }} type="link" key={1} onClick={() => handleOK(record)}>
          {record.status === 0 ? '发布' : '取消发布'}
        </Button>,
        <Button style={{ padding: 0 }} type="link" key={2} onClick={() => gotoEdit(record.newsId)}>
          编辑
        </Button>,
        <Popconfirm
          key={3}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.newsId)}
          okText="确定"
          cancelText="取消"
        >
          <Button style={{ padding: 0 }} type="link">
            删除
          </Button>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getNewsList}
        // expfunc={exportPersonList}
        toolBarRender={actions}
        actionRef={actionRef}
        columns={columns}
        rowKey="newsId"
        options={false}
        scroll={{ x: 1000 }}
      />
    </PageHeaderWrapper>
  );
};
